@@ -4,8 +4,6 @@
 use bevy::prelude::*;
 use bevy_ecs_ldtk::prelude::*;
 
-use bevy::render::{options::WgpuOptions, render_resource::WgpuLimits};
-
 use heron::prelude::*;
 
 mod components;
@@ -13,21 +11,16 @@ mod systems;
 
 fn main() {
     App::new()
-        .insert_resource(WgpuOptions {
-            limits: WgpuLimits {
-                max_texture_array_layers: 2048,
-                ..Default::default()
-            },
-            ..Default::default()
-        })
         .add_plugins(DefaultPlugins)
         .add_plugin(LdtkPlugin)
         .add_plugin(PhysicsPlugin::default())
         .insert_resource(Gravity::from(Vec3::new(0.0, -2000., 0.0)))
         .insert_resource(LevelSelection::Uid(0))
         .insert_resource(LdtkSettings {
-            load_level_neighbors: true,
-            use_level_world_translations: true,
+            level_spawn_behavior: LevelSpawnBehavior::UseWorldTranslation {
+                load_level_neighbors: true,
+            },
+            set_clear_color: SetClearColor::FromLevelBackground,
             ..Default::default()
         })
         .add_startup_system(systems::setup)
@@ -39,6 +32,7 @@ fn main() {
         .add_system(systems::patrol)
         .add_system(systems::camera_fit_inside_current_level)
         .add_system(systems::update_level_selection)
+        .add_system(systems::dbg_player_items)
         .register_ldtk_int_cell::<components::WallBundle>(1)
         .register_ldtk_int_cell::<components::LadderBundle>(2)
         .register_ldtk_int_cell::<components::WallBundle>(3)
