@@ -12,7 +12,7 @@ use std::{
 use crate::{
     assets::LdtkLevel,
     prelude::{LdtkEntity, LdtkIntCell},
-    resources::{LdtkSettings, LevelSelection},
+    resources::{LevelSelection, LevelSpawnBehavior},
     utils::ldtk_grid_coords_to_grid_coords,
 };
 
@@ -34,7 +34,8 @@ pub struct IntGridCell {
 /// [Component] that determines the desired levels to be loaded for an [LdtkWorldBundle].
 ///
 /// There is an abstraction for this in the form of the [LevelSelection] resource.
-/// This component does not respond to the [LdtkSettings] resource at all, while the
+/// This component does not respond to the
+/// [LevelSpawnBehavior::UseWorldTranslation::load_level_neighbors] option at all, while the
 /// [LevelSelection] does.
 /// If a [LevelSelection] is inserted, the plugin will update this component based off its value.
 /// If not, [LevelSet] allows you to have more direct control over the levels you spawn.
@@ -42,7 +43,7 @@ pub struct IntGridCell {
 /// Changes to this component are idempotent, so levels won't be respawned greedily.
 #[derive(Clone, Eq, PartialEq, Debug, Default, Component)]
 pub struct LevelSet {
-    pub uids: HashSet<i32>,
+    pub iids: HashSet<String>,
 }
 
 /// [Component] that indicates that an ldtk entity should be a child of the world, not the level.
@@ -55,17 +56,14 @@ pub struct LevelSet {
 /// so they can traverse levels without despawning.
 /// Furthermore, this component prevents respawns of the same entity if the level they were born in
 /// despawns/respawns.
-/// For this purpose, it uses the values stored in this component to uniquely identify ldtk
+/// For this purpose, it uses the `iid` stored in this component to uniquely identify ldtk
 /// entities.
 ///
 /// Implements [LdtkEntity], and can be added to an [LdtkEntity] bundle with the `#[worldly]` field
 /// attribute. See [LdtkEntity#worldly] for more details.
 #[derive(Clone, Eq, PartialEq, Debug, Default, Hash, Component)]
 pub struct Worldly {
-    pub spawn_level: i32,
-    pub spawn_layer: i32,
-    pub entity_def_uid: i32,
-    pub spawn_px: IVec2,
+    pub entity_iid: String,
 }
 
 impl Worldly {
@@ -74,15 +72,9 @@ impl Worldly {
     ///
     /// Used for the `#[worldly]` attribute macro for `#[derive(LdtkEntity)]`.
     /// See [LdtkEntity#worldly] for more info.
-    pub fn from_entity_info(
-        entity_instance: &EntityInstance,
-        layer_instance: &LayerInstance,
-    ) -> Worldly {
+    pub fn from_entity_info(entity_instance: &EntityInstance) -> Worldly {
         Worldly {
-            spawn_level: layer_instance.level_id,
-            spawn_layer: layer_instance.layer_def_uid,
-            entity_def_uid: entity_instance.def_uid,
-            spawn_px: entity_instance.px,
+            entity_iid: entity_instance.iid.clone(),
         }
     }
 }
@@ -129,6 +121,12 @@ impl From<TilePos> for GridCoords {
     }
 }
 
+impl From<GridCoords> for TilePos {
+    fn from(grid_coords: GridCoords) -> Self {
+        TilePos(grid_coords.x as u32, grid_coords.y as u32)
+    }
+}
+
 impl Add<GridCoords> for GridCoords {
     type Output = GridCoords;
     fn add(self, rhs: GridCoords) -> Self::Output {
@@ -181,6 +179,10 @@ impl MulAssign<GridCoords> for GridCoords {
 }
 
 impl GridCoords {
+    pub fn new(x: i32, y: i32) -> GridCoords {
+        GridCoords { x, y }
+    }
+
     /// Creates a [GridCoords] from the entity information available to the
     /// [LdtkEntity::bundle_entity] method.
     ///
@@ -194,6 +196,25 @@ impl GridCoords {
     }
 }
 
+/// [Component] for storing user-defined custom data for a paticular tile in an LDtk tileset
+/// definition.
+///
+/// Automatically inserted on any tiles with metadata.
+#[derive(Clone, Eq, PartialEq, Debug, Default, Hash, Component)]
+pub struct TileMetadata {
+    pub data: String,
+}
+
+/// [Component] for storing user-defined, enum-based tags for a particular tile in an LDtk tileset
+/// definition.
+///
+/// Automatically inserted on any tiles with enum tags.
+#[derive(Clone, Eq, PartialEq, Debug, Default, Hash, Component)]
+pub struct TileEnumTags {
+    pub tags: Vec<String>,
+    pub source_enum_uid: Option<i32>,
+}
+
 #[derive(Clone, Default, Bundle)]
 pub(crate) struct TileGridBundle {
     #[bundle]
