@@ -1,4 +1,5 @@
-//! An ECS-friendly ldtk plugin for [bevy](https://github.com/bevyengine/bevy). Uses
+//! An ECS-friendly [LDtk](https://ldtk.io/) plugin for
+//! [bevy](https://github.com/bevyengine/bevy). Uses
 //! [bevy_ecs_tilemap](https://github.com/StarArawn/bevy_ecs_tilemap) as a base.
 //!
 //! ### Getting Started
@@ -83,17 +84,18 @@
 //! component in the [LdtkWorldBundle].
 //! The [LevelSelection] resource is a convenient abstraction over the [LevelSet] component, and
 //! updates the [LevelSet] component automatically when used.
-//! It also responds to [LdtkSettings::load_level_neighbors], while [LevelSet] does not.
+//! It also responds to [LevelSpawnBehavior::UseWorldTranslation::load_level_neighbors], while
+//! [LevelSet] does not.
 //!
 //! To spawn a new level, you can just update the [LevelSelection] resource.
-//! The current level will be automatically despawned, unless it's still selected due to
-//! [LdtkSettings::load_level_neighbors].
+//! The current level will be automatically despawned, unless it's still selected due to loading
+//! level neighbors.
 //! Updating the [LevelSet] component will have similar results.
 //!
 //! By default, the levels will be spawned so their bottom left corner is at the origin of the
 //! world.
 //! You can make them spawn according to their world location in LDtk by setting
-//! [LdtkSettings::use_level_world_translations].
+//! [LevelSpawnBehavior::UseWorldTranslation].
 
 use bevy::prelude::*;
 use bevy_ecs_tilemap::prelude::*;
@@ -102,6 +104,7 @@ pub mod app;
 mod assets;
 mod components;
 pub mod ldtk;
+mod level;
 mod resources;
 pub mod systems;
 mod tile_makers;
@@ -190,10 +193,16 @@ pub mod prelude {
     pub use crate::{
         app::{LdtkEntity, LdtkIntCell, RegisterLdtkObjects},
         assets::{LdtkAsset, LdtkLevel},
-        components::{EntityInstance, GridCoords, IntGridCell, LdtkWorldBundle, LevelSet, Worldly},
+        components::{
+            EntityInstance, GridCoords, IntGridCell, LdtkWorldBundle, LevelSet, TileEnumTags,
+            TileMetadata, Worldly,
+        },
         ldtk::{self, FieldValue, LayerInstance, TilesetDefinition},
         plugin::LdtkPlugin,
-        resources::{LdtkSettings, LevelEvent, LevelSelection},
+        resources::{
+            IntGridRendering, LdtkSettings, LevelBackground, LevelEvent, LevelSelection,
+            LevelSpawnBehavior, SetClearColor,
+        },
     };
 
     #[cfg(feature = "derive")]
